==> speech-analytic-testing_1.9.0_database.tar.gz: database/mssql/procedures/SaveHistoricEvaluationPlanData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveHistoricEvaluationPlanData] (
	@VCC VARCHAR(50) = NULL,
	@FormatId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	IF(NOT EXISTS(SELECT [ID] FROM [dbo].[HistoricEvaluationFormat] (NOLOCK) WHERE [ID] = @FormatId))
	BEGIN
	
	     INSERT INTO [dbo].[HistoricEvaluationFormat] 
            SELECT 
            EF.[Instance],
            EF.[ID],
            EF.[Description],
            EF.[type],
            EF.[EnvironmentType],
            EF.[MinAutomaticQualification],
            EF.[MinQualificationAcceptable],
            EF.[ManagementFormURL],
            EF.[Enabled],
            EF.[templateId]
            FROM [dbo].[EvaluationFormat] EF (NOLOCK) 
            WHERE [ID] = @FormatId AND [Instance] = @VCC


		 
			INSERT INTO [dbo].[HistoricAbilityEvaluationFormat]
			SELECT
				A.[Instance],
				A.[ID] ,
				A.[IdEvaluationFormat],
				A.[IdAbility],
				A.[IdGroup],
				A.[IdSubGroup],
				A.[Penalizes],
				A.[Score],
				A.[Order],
				A.[Conditional]
				FROM  [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = A.[Instance] AND EF.[ID] = A.[IdEvaluationFormat]
				WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC


	END

	IF(NOT EXISTS(SELECT 
			ECF.[ID]
			FROM [dbo].[HistoricEvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[HistoricEvaluationFormat] EF (NOLOCK) 
			ON ECF.[VCC] = EF.[VCC] AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[VCC] = @VCC))
	BEGIN
			INSERT INTO [dbo].[HistoricEvaluationFormatCustomField]
			SELECT 
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order]
			FROM [dbo].[EvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK) 
			ON ECF.[VCC] = EF.[Instance] AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC
			GROUP BY
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order]
	END

	IF(NOT EXISTS(SELECT 
			 C.[ID]
			FROM [dbo].[HistoricCustomField] C (NOLOCK)
			JOIN [dbo].[HistoricEvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC))
	BEGIN
	INSERT INTO [dbo].[HistoricCustomField]
		SELECT 
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label]
			FROM [dbo].[CustomField] C (NOLOCK)
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY       
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label]
	END

	IF(NOT EXISTS(SELECT
			CR.[ID]
			FROM [dbo].[HistoricCustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[HistoricCustomField] C (NOLOCK)
			ON CR.[VCC] = C.[VCC] AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[HistoricEvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC))
	BEGIN
			INSERT INTO [dbo].[HistoricCustomFieldResult]
			SELECT
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId]
			FROM [dbo].[CustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[CustomField] C (NOLOCK)
			ON CR.[VCC] = C.[VCC] AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY 
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId]
	END

	IF(NOT EXISTS(SELECT 
				AFS.[VCC]
			FROM [dbo].[HistoricEvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId AND AFS.[VCC] = @VCC))
	BEGIN
			INSERT INTO 
			[dbo].[HistoricEvaluationFormatAttachedSignature]
			SELECT 
				AFS.[VCC],
				AFS.[Description],
				AFS.[Order],
				AFS.[EvaluationFormatId]
			FROM [dbo].[EvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId AND AFS.[VCC] = @VCC
	END

	
	IF(NOT EXISTS(SELECT
				CEF.[IdCampaign]
			FROM [dbo].[HistoricCampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId AND CEF.[VCC] = @VCC))
	BEGIN
			INSERT INTO [dbo].[HistoricCampaignEvaluationFormat]
			SELECT
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign]
			FROM [dbo].[CampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId AND CEF.[Instance] = @VCC
			GROUP BY 
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign]
	END


	IF(NOT EXISTS(
	SELECT G.[ID] FROM [dbo].[HistoricGroup] G (NOLOCK) 
    JOIN [dbo].[HistoricAbilityEvaluationFormat] A (NOLOCK)
			ON  A.[VCC] = G.[VCC] AND A.[IdGroup] = G.[ID]
            WHERE A.[IdEvaluationFormat] = @FormatId AND A.[VCC] = @VCC
	))
	BEGIN 
		        INSERT INTO [dbo].[HistoricGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled] 
				FROM [dbo].[Group] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled] 
	END


	IF(NOT EXISTS(
	SELECT G.[ID] FROM [dbo].[HistoricSubGroup] G (NOLOCK) 
    JOIN [dbo].[HistoricAbilityEvaluationFormat] A (NOLOCK)
			ON  A.[VCC] = G.[VCC] AND A.[IdSubGroup] = G.[ID]
            WHERE A.[IdEvaluationFormat] = @FormatId AND A.[VCC] = @VCC
	))
	BEGIN 
		        INSERT INTO [dbo].[HistoricSubGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled] 
				FROM [dbo].[SubGroup] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdSubGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				    G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled] 
	END

	IF(NOT EXISTS(
	SELECT AB.[ID] FROM [dbo].[HistoricAbility] AB (NOLOCK) 
    JOIN [dbo].[HistoricAbilityEvaluationFormat] A (NOLOCK)
			ON  A.[VCC] = AB.[VCC] AND A.[IdAbility] = AB.[ID]
            WHERE A.[IdEvaluationFormat] = @FormatId AND A.[VCC] = @VCC
	))
	BEGIN 
		        INSERT INTO [dbo].[HistoricAbility] 
				SELECT 
				A.[Instance],
                A.[ID],
                A.[Title],
                A.[Detail],
                A.[Type],
                A.[Binary],
                A.[NotApply],
                A.[Distribute],
                A.[AcceptComments],
                A.[Enabled],
                A.[AnalysisType],
                A.[Query],
                A.[QueryName],
                A.[Language],
                A.[IsNegative]
				FROM [dbo].[Ability] A (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  A.[Instance] = AEF.[Instance] AND AEF.[IdAbility] = A.[ID]
				WHERE AEF.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
	END

   IF(NOT EXISTS(SELECT AQ.[ID] FROM [dbo].[HistoricAbilityQuery] AQ (NOLOCK)
                 JOIN [dbo].[HistoricAbilityEvaluationFormat] AEF (NOLOCK)
                 ON  AQ.[VCC] = AEF.[VCC] AND AEF.[IdAbility] = AQ.[AbilityId]
				 WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC))
   BEGIN
		INSERT INTO [dbo].[HistoricAbilityQuery]
		SELECT 
			AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order]
		FROM [dbo].[AbilityQuery] AQ (NOLOCK)
		JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
		WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC
		GROUP BY 
		    AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order]
  END

  IF(NOT EXISTS( SELECT 
                AQE.[VCC]
                FROM [dbo].[HistoricAbilityQueryEntity] AQE (NOLOCK)
                JOIN [dbo].[HistoricAbilityQuery] AQ (NOLOCK)
                ON AQ.[VCC] = AQE.[VCC] AND AQE.[AbilityQueryId] = AQ.[ID]
                JOIN [dbo].[HistoricAbilityEvaluationFormat] AEF (NOLOCK)
                ON  AQ.[VCC] = AEF.[VCC] AND AEF.[IdAbility] = AQ.[AbilityId]
				WHERE AQ.[VCC] = @VCC AND AEF.[IdEvaluationFormat] = @FormatId))

			   INSERT INTO [dbo].[HistoricAbilityQueryEntity]
						    SELECT 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order]
							FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
							JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
							ON AQ.[VCC] = AQE.[VCC] AND AQE.[AbilityQueryId] = AQ.[ID]
							JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
							ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
							WHERE AQ.[VCC] = @VCC AND AEF.[IdEvaluationFormat] = @FormatId
							GROUP BY 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order]
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.1.3_database.tar.gz: database/mssql/procedures/SaveHistoricEvaluationPlanData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveHistoricEvaluationPlanData] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50)=NULL,
	@FormatId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	
	     INSERT INTO [dbo].[HistoricEvaluationFormat] 
            SELECT 
            EF.[Instance],
            EF.[ID],
            EF.[Description],
            EF.[type],
            EF.[EnvironmentType],
            EF.[MinAutomaticQualification],
            EF.[MinQualificationAcceptable],
            EF.[ManagementFormURL],
            EF.[Enabled],
            EF.[templateId],
			@EvaluationPlanId
            FROM [dbo].[EvaluationFormat] EF (NOLOCK) 
            WHERE [ID] = @FormatId AND [Instance] = @VCC


		 
			INSERT INTO [dbo].[HistoricAbilityEvaluationFormat]
			SELECT
				A.[Instance],
				A.[ID] ,
				A.[IdEvaluationFormat],
				A.[IdAbility],
				A.[IdGroup],
				A.[IdSubGroup],
				A.[Penalizes],
				A.[Score],
				A.[Order],
				A.[Conditional],
				@EvaluationPlanId
				FROM  [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = A.[Instance] AND EF.[ID] = A.[IdEvaluationFormat]
				WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC


			INSERT INTO [dbo].[HistoricEvaluationFormatCustomField]
			SELECT 
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order],
			@EvaluationPlanId
			FROM [dbo].[EvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK) 
			ON ECF.[VCC] = EF.[Instance] AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC
			GROUP BY
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order]


	    INSERT INTO [dbo].[HistoricCustomField]
		SELECT 
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label],
			 @EvaluationPlanId
			FROM [dbo].[CustomField] C (NOLOCK)
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY       
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label]



			INSERT INTO [dbo].[HistoricCustomFieldResult]
			SELECT
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId],
			@EvaluationPlanId
			FROM [dbo].[CustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[CustomField] C (NOLOCK)
			ON CR.[VCC] = C.[VCC] AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY 
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId]
	
	

			INSERT INTO 
			[dbo].[HistoricEvaluationFormatAttachedSignature]
			SELECT 
				AFS.[VCC],
				AFS.[Description],
				AFS.[Order],
				AFS.[EvaluationFormatId],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId AND AFS.[VCC] = @VCC


	
			INSERT INTO [dbo].[HistoricCampaignEvaluationFormat]
			SELECT
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign],
				@EvaluationPlanId
			FROM [dbo].[CampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId AND CEF.[Instance] = @VCC
			GROUP BY 
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign]



		        INSERT INTO [dbo].[HistoricGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled],
					@EvaluationPlanId
				FROM [dbo].[Group] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled] 
	



		        INSERT INTO [dbo].[HistoricSubGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled],
					@EvaluationPlanId
				FROM [dbo].[SubGroup] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdSubGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				    G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled] 



		        INSERT INTO [dbo].[HistoricAbility] 
				SELECT 
				A.[Instance],
                A.[ID],
                A.[Title],
                A.[Detail],
                A.[Type],
                A.[Binary],
                A.[NotApply],
                A.[Distribute],
                A.[AcceptComments],
                A.[Enabled],
                A.[AnalysisType],
                A.[Query],
                A.[QueryName],
                A.[Language],
                A.[IsNegative],
                @EvaluationPlanId
				FROM [dbo].[Ability] A (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  A.[Instance] = AEF.[Instance] AND AEF.[IdAbility] = A.[ID]
				WHERE AEF.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC


		INSERT INTO [dbo].[HistoricAbilityQuery]
		SELECT 
			AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order],
			@EvaluationPlanId
		FROM [dbo].[AbilityQuery] AQ (NOLOCK)
		JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
		WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC
		GROUP BY 
		    AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order]


			   INSERT INTO [dbo].[HistoricAbilityQueryEntity]
						    SELECT 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order],
							@EvaluationPlanId
							FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
							JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
							ON AQ.[VCC] = AQE.[VCC] AND AQE.[AbilityQueryId] = AQ.[ID]
							JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
							ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
							WHERE AQ.[VCC] = @VCC AND AEF.[IdEvaluationFormat] = @FormatId
							GROUP BY 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order]
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
